/**
 * Deeply assigns the values of all enumerable-own-properties from one or more source objects to a
 * target object. Returns the target object.
 *
 * Almost identical to `services/api/src/utils/assignWithEmptyObjects.js`,
 * which in turn is based on assign-deep (https://github.com/jonschlinkert/assign-deep/)
 *
 * Only difference to `services/api` version is that we delete keys if the value in the source
 * object is `undefined` instead of `null`
 */
declare function assignWithEmptyObjects<TObject>(target: TObject): TObject;
declare function assignWithEmptyObjects<TObject, TSource>(target: TObject, source: TSource): TObject & TSource;
declare function assignWithEmptyObjects<TObject, TSource1, TSource2>(target: TObject, source1: TSource1, source2: TSource2): TObject & TSource1 & TSource2;
declare function assignWithEmptyObjects<TObject, TSource1, TSource2, TSource3>(target: TObject, source1: TSource1, source2: TSource2, source3: TSource3): TObject & TSource1 & TSource2 & TSource3;
declare function assignWithEmptyObjects<TObject, TSource1, TSource2, TSource3, TSource4>(target: TObject, source1: TSource1, source2: TSource2, source3: TSource3, source4: TSource4): TObject & TSource1 & TSource2 & TSource3 & TSource4;
export default assignWithEmptyObjects;
