"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.columnFormatter = void 0;
const dateColumnFormatter_js_1 = __importDefault(require("./dateColumnFormatter.cjs"));
const numberColumnFormatter_js_1 = __importDefault(require("./numberColumnFormatter.cjs"));
const get_js_1 = __importDefault(require("./get.cjs"));
const identity = (d) => d;
/**
 * Creates a column formatter
 *
 * @exports columnFormatter
 * @kind function
 *
 * @description
 * This function returns a formatting function based, given a column object,
 * a metadata object and the axis column name.
 *
 * @param numeral - Numeral.js instance
 * @param column - the date column object
 * @param metadata - the full metadata object
 * @param axis - the column name of the axis
 * @returns formatting function
 */
function columnFormatter(numeral, column, metadata, axis, options = {}) {
    return column.type() === 'date'
        ? (0, dateColumnFormatter_js_1.default)(column.type(true), options)
        : column.type() === 'number'
            ? (0, numberColumnFormatter_js_1.default)(numeral, (0, get_js_1.default)(metadata, `data.column-format.${axis}`, {}))
            : identity;
}
exports.columnFormatter = columnFormatter;
