type Callback = (res: any) => void;
type ResultPromise = Promise<any>;
/**
 * Download and parse a remote JSON document. Use {@link httpReq} instead
 *
 * @deprecated
 *
 * @param {string} url
 * @param {string} method - HTTP method, either GET, POST or PUT
 * @param {string|undefined} credentials - set to "include" if cookies should be passed along CORS requests
 * @param {string} body
 * @param {function} callback
 *
 * @returns {Promise}
 *
 * @example
 * import { fetchJSON } from '@datawrapper/shared/fetch';
 * fetchJSON('http://api.example.org', 'GET', 'include');
 */
export declare function fetchJSON(url: string, method: string, credentials: RequestCredentials | undefined, body: string | null, callback?: Callback): Promise<any>;
/**
 * Download and parse a JSON document via GET.
 * Use {@link httpReq} or {@link httpReq.get} instead.
 *
 * @deprecated
 *
 * @param {string} url
 * @param {function} callback
 *
 * @returns {Promise}
 *
 * @example
 * import { getJSON } from '@datawrapper/shared/fetch';
 * // use it callback style
 * getJSON('http://api.example.org', function(data) {
 *     console.log(data);
 * });
 * // or promise-style
 * getJSON('http://api.example.org')
 *   .then(data => {
 *      console.log(data);
 *   });
 */
declare function getJSON(url: string, callback: Callback): ResultPromise;
/**
 * Download and parse a JSON document via GET.
 * Use {@link httpReq} or {@link httpReq.get} instead.
 *
 * @deprecated
 *
 * @param {string} url
 * @param {string|undefined} credentials - optional, set to undefined to disable credentials
 * @param {function} callback
 *
 * @returns {Promise}
 *
 * @example
 * import { getJSON } from '@datawrapper/shared/fetch';
 * // use it callback style
 * getJSON('http://api.example.org', 'include', function(data) {
 *     console.log(data);
 * });
 * // or promise-style
 * getJSON('http://api.example.org')
 *   .then(data => {
 *      console.log(data);
 *   });
 */
declare function getJSON(url: string, credentials?: RequestCredentials, callback?: Callback): ResultPromise;
export { getJSON };
/**
 * Download and parse a remote JSON endpoint via POST. credentials
 * are included automatically.
 * Use {@link httpReq} or {@link httpReq.post} instead.
 *
 * @deprecated
 *
 * @param {string} url
 * @param {string} body
 * @param {function} callback
 *
 * @returns {Promise}
 * @example
 * import { postJSON } from '@datawrapper/shared/fetch';
 *
 * postJSON('http://api.example.org', JSON.stringify({
 *    query: 'foo',
 *    page: 12
 * }));
 */
export declare function postJSON(url: string, body: string, callback?: Callback): Promise<any>;
/**
 * Download and parse a remote JSON endpoint via PUT. credentials
 * are included automatically
 * Use {@link httpReq} or {@link httpReq.put} instead.
 *
 * @deprecated
 *
 * @param {string} url
 * @param {string} body
 * @param {function} callback
 *
 * @returns {Promise}
 * @example
 * import { putJSON } from '@datawrapper/shared/fetch';
 *
 * putJSON('http://api.example.org', JSON.stringify({
 *    query: 'foo',
 *    page: 12
 * }));
 */
export declare function putJSON(url: string, body: string, callback?: Callback): Promise<any>;
/**
 * @deprecated use httpReq or httpReq.patch instead
 *
 * Download and parse a remote JSON endpoint via PATCH. credentials
 * are included automatically
 *
 * @param {string} url
 * @param {string} body
 * @param {function} callback
 *
 * @returns {Promise}
 * @example
 * import { patchJSON } from '@datawrapper/shared/fetch';
 *
 * patchJSON('http://api.example.org', JSON.stringify({
 *    query: 'foo',
 *    page: 12
 * }));
 */
export declare function patchJSON(url: string, body: string, callback?: Callback): Promise<any>;
/**
 * Download and parse a remote JSON endpoint via DELETE. credentials
 * are included automatically
 * Use {@link httpReq} or {@link httpReq.delete} instead.
 *
 * @deprecated
 *
 * @param {string} url
 * @param {function} callback
 *
 * @returns {Promise}
 *
 * @example
 * import { deleteJSON } from '@datawrapper/shared/fetch';
 *
 * deleteJSON('http://api.example.org/chart/123').then(() => {
 *     console.log('deleted!')
 * });
 */
export declare function deleteJSON(url: string, callback?: Callback): Promise<any>;
/**
 * injects a `<script>` element to the page to load a new JS script
 *
 * @param {string} src
 * @param {function} callback
 *
 * @example
 * import { loadScript } from '@datawrapper/shared/fetch';
 *
 * loadScript('/static/js/library.js', () => {
 *     console.log('library is loaded');
 * })
 */
export declare function loadScript(src: string, callback?: (() => void) | null): Promise<void>;
/**
 * @typedef {object} opts
 * @property {string} src - stylesheet URL to load
 * @property {DOMElement} parentElement - DOM element to append style tag to
 */
type LoadStylesheetOptions = {
    src: string;
    parentElement?: HTMLElement;
};
/**
 * injects a `<link>` element to the page to load a new stylesheet
 *
 * @param {string|opts} src
 * @param {function} callback
 *
 * @example
 * import { loadStylesheet } from '@datawrapper/shared/fetch';
 *
 * loadStylesheet('/static/css/library.css', () => {
 *     console.log('library styles are loaded');
 * })
 */
export declare function loadStylesheet(_opts: string | LoadStylesheetOptions, callback?: (() => void) | null): Promise<void>;
