"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const d3_color_1 = require("d3-color");
const get_js_1 = __importDefault(require("./get.cjs"));
/**
 * returns the color used by overlays
 *
 * @exports getOverlayColor
 * @kind function
 *
 * @param {object} overlay
 * @param {object} theme -- theme data for a chart
 *
 * @export
 * @returns {string}
 */
function getOverlayColor(overlay, theme) {
    const palette = (0, get_js_1.default)(theme, 'colors.palette', []);
    function getColor(c) {
        if (typeof c === 'number') {
            return palette[c % palette.length];
        }
        return c;
    }
    let overlayColor = getColor(overlay.color).toLowerCase();
    overlayColor = `rgba(${(0, d3_color_1.rgb)(overlayColor).r},${(0, d3_color_1.rgb)(overlayColor).g},${(0, d3_color_1.rgb)(overlayColor).b}, ${Number(overlay.opacity)})`;
    return overlayColor;
}
exports.default = getOverlayColor;
