/**
 * A delayed highlight setter
 *
 * @exports highlightTimer
 * @kind function
 *
 * @example
 * import {highlightTimer} from '@datawrapper/shared';
 * const myTimer = highlightTimer(value => {
 *     if (value) {
 *         selection.style('opacity', d => d === value ? 1 : 0.3);
 *     } else {
 *         selection.style('opacity', 1);
 *     }
 * });
 *
 * lines.on('mouseenter', d => myTimer.set(d));
 * chart.on('mouseleave', myTimer.clear);
 *
 * @param {function} action - the highlight action callback
 * @param {int} delay - how long something needs to be highlighted before
 *		the highlight triggers (in milliseconds)
 * @returns {object}
 */
export default function highlightTimer(action: (highlighted: boolean | null) => void, delay?: number): {
    set(value: boolean): void;
    clear(): void;
    get(): boolean | null;
};
