import { ThemeData } from '../themeTypes.js';
/**
 * defines colors for the various chart elements like axis text, gridlines,
 * bar background etc. based on the theme background color, and some other optional theme parameters
 *
 * @exports defaultColors
 * @kind function
 *
 * @example
 * // returns {"tickText":{"secondary":"#9d9d9d","primary":"#d9d9d9"},"series":"#f1f1f1","value":"#d9d9d9","axis":"#f1f1f1","gridline":"#707070","fallbackBaseColor":"#f1f1f1"}
 * defaultColors({"colors": {"background": "#333333"}});
 *
 * @example
 * // returns {"tickText":{"secondary":"#ffffff","primary":"#ffffff"},"series":"#ffffff","value":"#fef2e4","axis":"#ffffff","gridline":"#fedeb5","fallbackBaseColor":"#ffffff"}
 * defaultColors({"colors": {"bgBlendRatios": {"gridline": 0.5,"tickText": {"primary": 0,"secondary": 0}},"chartContentBaseColor": "#ffffff","background": "#FCB716"}});

 * @param themeData -- theme data for a chart
 * @param chroma -- chroma instance
 * @returns -- object with color definitions and blendColor function
 */
export declare function defaultColors(themeData: ThemeData, chroma: typeof import('chroma-js')): {
    tickText: {
        secondary: string;
        primary: string;
    };
    series: string;
    value: string;
    axis: string;
    gridline: string;
    fallbackBaseColor: string;
    blendColor(blendRatio: number): string;
};
