"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const memoizer_js_1 = require("../memoizer.cjs");
const DEFAULT_ALLOWED = [
    'a',
    'span',
    'b',
    'br',
    'i',
    'strong',
    'sup',
    'sub',
    'strike',
    'u',
    'em',
    'tt'
].sort();
const MEMOIZER_MAXSIZE = 100000;
const memoizer = (0, memoizer_js_1.createPermanentMemoizer)((DOMPurify) => DOMPurify.version, DOMPurify => {
    /**
     * Set default TARGET and REL for A tags.
     *
     * Don't overwrite target="_self".
     */
    DOMPurify.addHook('afterSanitizeElements', function (el) {
        if (el.nodeName.toLowerCase() === 'a') {
            if (el.getAttribute('target') !== '_self') {
                el.setAttribute('target', '_blank');
            }
            el.setAttribute('rel', 'nofollow noopener noreferrer');
        }
    });
    return (0, memoizer_js_1.createPermanentMemoizer)((allowedTagsInput) => String(allowedTagsInput), allowedTagsInput => {
        const allowedTags = allowedTagsInput === undefined
            ? DEFAULT_ALLOWED
            : typeof allowedTagsInput === 'string'
                ? allowedTagsInput.toLowerCase().slice(1, -1).split('><')
                : allowedTagsInput;
        const config = {
            ALLOWED_TAGS: allowedTags,
            ADD_ATTR: ['target'],
            FORCE_BODY: true // Makes sure that top-level SCRIPT tags are kept if explicitly allowed.
        };
        return (0, memoizer_js_1.createPermanentMemoizer)((input) => input, input => {
            // Implementation of DOMPurify accepts anything,
            // and we need to accept anything too, according to tests
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            return DOMPurify.sanitize(input, config);
        }, { maxsize: MEMOIZER_MAXSIZE });
    }, { maxsize: MEMOIZER_MAXSIZE });
});
/**
 * Generates an instance of purifyHtml with DOMPurify already loaded.
 *
 * @exports purifyHtmlFactory
 * @kind function
 *
 * @param DOMPurify - DOMPurify instance
 */
function purifyHtmlFactory(DOMPurify) {
    return function purifyHtml(input, allowedTagsInput) {
        if (!input) {
            return input;
        }
        return memoizer.get(DOMPurify, true).get(allowedTagsInput).get(input);
    };
}
exports.default = purifyHtmlFactory;
