"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const significantDimension_js_1 = __importDefault(require("./significantDimension.cjs"));
const round_js_1 = __importDefault(require("./round.cjs"));
/**
 * rounds an array of numbers to the least number of decimals
 * without loosing any information due to the rounding
 *
 * @exports smartRound
 * @kind function
 *
 * @example
 * import {smartRound} from '@datawrapper/shared/smartRound';
 * smartRound([9, 10.5714, 12.1428, 13.7142]); // [9, 11, 12, 14]
 * smartRound([9, 10.5714, 12.1428, 12.4142]); // [9, 10.6, 12.1, 12.4]
 *
 * @param {array} values - the numbers to be rounded
 * @param {number} addPrecision - force more precision (=numbers of decimals) to the rounding
 * @param {number} tolerance - the percent of uniq input values that we can tolerate to lose after rounding
 * @returns the rounded values
 */
function smartRound(values, addPrecision = 0, tolerance = 0.1) {
    let dim = (0, significantDimension_js_1.default)(values, tolerance);
    dim += addPrecision;
    return values.map(v => (0, round_js_1.default)(v, dim));
}
exports.default = smartRound;
