export type Typography = {
    fontFamilies: Record<string, {
        name: string;
        weight: number;
        style: string;
    }[]>;
};
export type FontObject = {
    family: string;
    props: {
        weight: number;
        style: string;
    };
};
type ThemeBlockStyles = {
    gap?: number;
    layout?: string;
    flexGrow?: number;
    maxWidth?: string;
    minWidth?: string;
    separator?: {
        margin?: string;
    };
    tabs?: any;
    typography?: {
        color?: string;
        fontSize?: number;
        fontWeight?: number | string;
        lineHeight?: number;
        typeface?: string;
        underlined?: boolean;
    };
};
type ThemeBlockData = {
    options?: {
        id?: string;
        title?: string;
        height?: number;
        imgSrc?: string;
    }[];
};
type ThemeBlock = {
    styles?: ThemeBlockStyles & {
        links?: ThemeBlockStyles;
    };
    data?: ThemeBlockData;
};
export type Block = {
    id?: string;
    type?: string;
    children?: {
        id?: string;
        type?: string;
    }[];
};
export type Container = Block & {
    type: 'container';
    children: Block[];
};
type FontWeight = 'bold' | 'bolder' | 'light' | 'lighter' | 'normal' | 'initial' | 100 | 200 | 300 | 400 | 500 | 600 | 700 | 800 | 900;
type TextTransform = 'uppercase' | 'capitalize' | 'lowercase' | 'full-width' | 'none';
type TypographyObject = {
    color?: string;
    fontSize?: number;
    fontWeight?: FontWeight;
    typeface?: string;
    lineHeight?: number;
    textTransform?: TextTransform;
    letterSpacing?: string;
};
export type ThemeData = {
    type?: 'web' | 'print';
    blocks?: Record<string, ThemeBlock>;
    regions?: {
        header?: Container;
        footer?: Container;
        bodyLeft?: Container;
        bodyRight?: Container;
        afterChart?: Block[];
    };
    colors?: {
        background?: string;
        bgBlendRatios?: {
            axis?: number;
            gridline?: number;
            series?: number;
            tickText?: {
                primary?: number;
                secondary?: number;
            };
            value?: number;
        };
        chartContentBaseColor?: string;
        general?: {
            background?: string;
            padding?: number;
        };
        palette?: string[];
    };
    easing?: string;
    typography?: {
        chart?: {
            fontSize?: number;
        };
    };
    vis?: {
        'multiple-lines'?: {
            labels?: {
                panelTitles?: TypographyObject;
            };
        };
    };
};
/**
 * @deprecated Please use ThemeData instead
 */
export type Theme = ThemeData;
export {};
