import { Column, DatePrecision } from './chartTypes.js';
/**
 * auto-detects a nice default axis tick format for numeric
 * columns based on the input range
 *
 * @example
 * import {autoTickFormatNumber} from '@datawrapper/shared/autoTickFormat';
 * autoTickFormatNumber([0,100]); // '0,0.[00]'
 * autoTickFormatNumber([0.2,0.7]); // '0,0.00[00]'
 *
 * @param {array} range - [min, max] of the data
 * @returns {string} - numeral.js compatible format string
 */
export declare function autoTickFormatNumber(range: [number, number]): "0,0.00[0]" | "0,0.0[0]" | "0,0.[0]" | "0,0.[0]a" | "0,0";
/**
 * auto-detects a nice default axis tick format for date
 * columns based on the input range and precision
 *
 * @example
 * import {autoTickFormatDate} from '@datawrapper/shared/autoTickFormat';
 * autoTickFormatDate([new Date(2000,0,1), new Date(2002,0,1)], 'quarter'); // 'YYYY|[Q]Q'
 *
 * @param {array} range - [min, max] of the data
 * @param {string} precision - the input data precision (year|quarter|month|week|day|...)
 * @returns {string} - day.js compatible format string
 */
export declare function autoTickFormatDate(range: [Date, Date], precision?: DatePrecision): "YYYY~~'YY" | "YYYY" | "YYYY|MMM" | "YYYY|[Q]Q" | "YYYY [Q]Q|MMM" | "YYYY|[W]wo" | "LTS" | "LT" | "dddd|LT" | "MMMM|D" | "MMM|D" | "YYYY|MMM|D";
/**
 * Convenient wrapper around autoTickFormatNumber and autoTickFormatDate.
 * Returns either a numeral.js or day.js format, depending on the column type.
 *
 * @exports autoTickFormat
 * @kind function
 *
 * @param {object} column -- dw.column instance that is displayed on the axis
 * @returns {string} -- a numeral|dayjs format string
 */
export declare function autoTickFormat(column: Column, range: [any, any]): false | "0,0.00[0]" | "0,0.0[0]" | "0,0.[0]" | "0,0.[0]a" | "0,0" | "YYYY~~'YY" | "YYYY" | "YYYY|MMM" | "YYYY|[Q]Q" | "YYYY [Q]Q|MMM" | "YYYY|[W]wo" | "LTS" | "LT" | "dddd|LT" | "MMMM|D" | "MMM|D" | "YYYY|MMM|D";
