import dateColumnFormatter from './dateColumnFormatter.js';
import numberColumnFormatter from './numberColumnFormatter.js';
import get from './get.js';
const identity = (d) => d;
/**
 * Creates a column formatter
 *
 * @exports columnFormatter
 * @kind function
 *
 * @description
 * This function returns a formatting function based, given a column object,
 * a metadata object and the axis column name.
 *
 * @param numeral - Numeral.js instance
 * @param column - the date column object
 * @param metadata - the full metadata object
 * @param axis - the column name of the axis
 * @returns formatting function
 */
export function columnFormatter(numeral, column, metadata, axis, options = {}) {
    return column.type() === 'date'
        ? dateColumnFormatter(column.type(true), options)
        : column.type() === 'number'
            ? numberColumnFormatter(numeral, get(metadata, `data.column-format.${axis}`, {}))
            : identity;
}
