/**
 * Inverts a color to have a similar contrast against an inverted background
 *
 * Accepts color definitions in formats supported by chroma.js
 * (e.g. 'red', '#FF0000', [255, 0, 0])
 *
 * @exports invertColor
 * @kind function
 *
 * @param {string|Array|Object} baseColor - the color to be inverted
 * @param {string|Array|Object} darkBackgroundColor - the inverted background color
 * @param {string|Array|Object} lightBackgroundColor - the original background color
 * @param {number} gamma - gamma exponent for lightness correction
 *
 * @example
 * import invertColor from '@datawrapper/shared/invertColor.cjs';

 * const darkModeColor = invertColor('#ff99gg', 'black', 'white');
 *
 * @export
 * @returns {string} hex color
 */
declare function invertColor(baseColor: string, darkBackgroundColor: string, lightBackgroundColor: string, gamma?: number): string;
export default invertColor;
