/**
 * Performs one-dimensional k-means clustering on an array of
 * numbers. Useful for finding n groups of "similar values".
 *
 * @exports kMeans
 * @kind function
 *
 * @example
 * import kMeans from '@datawrapper/shared/kMeans';
 *
 * const values = [1, 1.1, 1.2, 2.1, 3, 3.1, 3.2, 3.3, 7, 7.1, 10];
 * // returns [[1, 1.1, 1.2, 2.1], [3, 3.1, 3.2, 3.3], [7, 7.1, 10]]
 * kMeans(values, 3)
 *
 * @param {number[]} values - sorted array of numbers
 * @param {number} numCluster - the desired cluster count
 * @returns {array.<number[]>} - array of clusters
 */
export default function kMeans(values: number[], numClusters: number): number[][];
