import { BrowserWindow } from './browserGlobals.js';
declare global {
    interface Window extends BrowserWindow {
    }
}
/**
 * Translates a message key, replaces placeholders within translated strings, and sanitizes the
 * result of the translation so that it can be safely used in HTML.
 *
 * @param key -- the key to be translated, e.g. "signup / hed"
 * @param scope -- the translation scope, e.g. "core" or a plugin name
 * @param messages -- translation strings in the format of { scope: { key: value }}
 * @param replacements -- replacements for placeholders in the translations strings
 * @returns -- the translated text
 */
export declare function translate(key: string, scope: string | undefined, messages: Record<string, Record<string, string>>, ...replacements: string[] | Record<string, unknown>[]): string;
/**
 * Helper for finding a translation key based on a globally accessible dictionary (to be used
 * e.g. in visualization plugins and legacy Svelte 2 code).
 *
 * Translates a message key, replaces placeholders within translated strings, and sanitizes the
 * result of the translation so that it can be safely used in HTML.
 *
 * For the client-side translation to work we are pulling the translations from the global
 * `window.dw.backend.__messages` object. plugins that need client-side translations must set
 * `"svelte": true` in their plugin.json.
 *
 * @param key -- the key to be translated, e.g. "signup / hed"
 * @param scope -- the translation scope, e.g. "core" or a plugin name
 * @param replacements -- replacements for placeholders in the translations strings
 * @returns -- the translated text
 */
export declare function __(key: string, scope?: string, ...replacements: string[] | Record<string, unknown>[]): string;
export declare function keyExists(key: string, scope?: string): boolean;
