/**
 * Recursively compares two objects and returns the
 * "merge patch" object which can be deep-assigned to
 * the source to create the target
 *
 * @exports objectDiff
 * @kind function
 *
 * @example
 * import objectDiff from '@datawrapper/shared/objectDiff';
 * objectDiff({ foo: 1, bar: 'hello' }, { foo: 1, bar: 'world' });
 * // returns { bar: 'world' }
 *
 * @param {object} source - the original object
 * @param {object} target - the changed object
 * @param {array} allowedKeys - if given, the diff will
 *     ignore any first-level keys not in this array
 *
 * @returns {object} - the merge patch
 */
export default function objectDiff<TSource, TTarget>(source: TSource, target: TTarget, allowedKeys?: ((keyof TSource | keyof TTarget) & string)[] | null): Record<string, unknown>;
